@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -30,7 +30,9 @@ function condition_operator2str($operator) {
 		CONDITION_OPERATOR_LESS_EQUAL => _('is less than or equals'),
 		CONDITION_OPERATOR_NOT_IN => _('not in'),
 		CONDITION_OPERATOR_YES => _('Yes'),
-		CONDITION_OPERATOR_NO => _('No')
+		CONDITION_OPERATOR_NO => _('No'),
+		CONDITION_OPERATOR_REGEXP => _('matches'),
+		CONDITION_OPERATOR_NOT_REGEXP => _('does not match')
 	];
 
 	return $operators[$operator];
@@ -983,41 +985,41 @@ function getActionOperationHints(array $operations, array $defaultMessage) {
  */
 function get_conditions_by_eventsource($eventsource) {
 	$conditions[EVENT_SOURCE_TRIGGERS] = [
-		CONDITION_TYPE_APPLICATION,
-		CONDITION_TYPE_HOST_GROUP,
-		CONDITION_TYPE_TEMPLATE,
-		CONDITION_TYPE_HOST,
-		CONDITION_TYPE_TRIGGER,
 		CONDITION_TYPE_TRIGGER_NAME,
+		CONDITION_TYPE_TRIGGER,
 		CONDITION_TYPE_TRIGGER_SEVERITY,
-		CONDITION_TYPE_TIME_PERIOD,
+		CONDITION_TYPE_APPLICATION,
+		CONDITION_TYPE_HOST,
+		CONDITION_TYPE_HOST_GROUP,
 		CONDITION_TYPE_SUPPRESSED,
 		CONDITION_TYPE_EVENT_TAG,
-		CONDITION_TYPE_EVENT_TAG_VALUE
+		CONDITION_TYPE_EVENT_TAG_VALUE,
+		CONDITION_TYPE_TEMPLATE,
+		CONDITION_TYPE_TIME_PERIOD
 	];
 	$conditions[EVENT_SOURCE_DISCOVERY] = [
 		CONDITION_TYPE_DHOST_IP,
-		CONDITION_TYPE_DSERVICE_TYPE,
-		CONDITION_TYPE_DSERVICE_PORT,
-		CONDITION_TYPE_DRULE,
 		CONDITION_TYPE_DCHECK,
 		CONDITION_TYPE_DOBJECT,
+		CONDITION_TYPE_DRULE,
 		CONDITION_TYPE_DSTATUS,
-		CONDITION_TYPE_DUPTIME,
+		CONDITION_TYPE_PROXY,
 		CONDITION_TYPE_DVALUE,
-		CONDITION_TYPE_PROXY
+		CONDITION_TYPE_DSERVICE_PORT,
+		CONDITION_TYPE_DSERVICE_TYPE,
+		CONDITION_TYPE_DUPTIME
 	];
 	$conditions[EVENT_SOURCE_AUTO_REGISTRATION] = [
 		CONDITION_TYPE_HOST_NAME,
-		CONDITION_TYPE_PROXY,
-		CONDITION_TYPE_HOST_METADATA
+		CONDITION_TYPE_HOST_METADATA,
+		CONDITION_TYPE_PROXY
 	];
 	$conditions[EVENT_SOURCE_INTERNAL] = [
 		CONDITION_TYPE_APPLICATION,
 		CONDITION_TYPE_EVENT_TYPE,
+		CONDITION_TYPE_HOST,
 		CONDITION_TYPE_HOST_GROUP,
-		CONDITION_TYPE_TEMPLATE,
-		CONDITION_TYPE_HOST
+		CONDITION_TYPE_TEMPLATE
 	];
 
 	if (isset($conditions[$eventsource])) {
@@ -1266,14 +1268,18 @@ function get_operators_by_conditiontype($conditiontype) {
 	];
 	$operators[CONDITION_TYPE_HOST_NAME] = [
 		CONDITION_OPERATOR_LIKE,
-		CONDITION_OPERATOR_NOT_LIKE
+		CONDITION_OPERATOR_NOT_LIKE,
+		CONDITION_OPERATOR_REGEXP,
+		CONDITION_OPERATOR_NOT_REGEXP
 	];
 	$operators[CONDITION_TYPE_EVENT_TYPE] = [
 		CONDITION_OPERATOR_EQUAL
 	];
 	$operators[CONDITION_TYPE_HOST_METADATA] = [
 		CONDITION_OPERATOR_LIKE,
-		CONDITION_OPERATOR_NOT_LIKE
+		CONDITION_OPERATOR_NOT_LIKE,
+		CONDITION_OPERATOR_REGEXP,
+		CONDITION_OPERATOR_NOT_REGEXP
 	];
 	$operators[CONDITION_TYPE_EVENT_TAG] = [
 		CONDITION_OPERATOR_EQUAL,
